@@ -276,26 +276,6 @@ const guint8 *qmi_message_get_raw (QmiMessage  *self,
 
 /*****************************************************************************/
 /* Version support from the database */
-
-/**
- * qmi_message_get_version_introduced:
- * @self: a #QmiMessage.
- * @major: (out) return location for the major version.
- * @minor: (out) return location for the minor version.
- *
- * Gets, if known, the service version in which the given message was first
- * introduced.
- *
- * Returns: %TRUE if @major and @minor are set, %FALSE otherwise.
- *
- * Since: 1.0
- * Deprecated: 1.18: Use qmi_message_get_version_introduced_full() instead.
- */
-G_DEPRECATED_FOR (qmi_message_get_version_introduced_full)
-gboolean qmi_message_get_version_introduced (QmiMessage *self,
-                                             guint      *major,
-                                             guint      *minor);
-
 /**
  * qmi_message_get_version_introduced_full:
  * @self: a #QmiMessage.
@@ -830,10 +810,11 @@ gboolean qmi_message_tlv_read_sized_guint (QmiMessage  *self,
                                            GError     **error);
 
 /**
- * qmi_message_tlv_read_gfloat:
+ * qmi_message_tlv_read_gfloat_endian:
  * @self: a #QmiMessage.
  * @tlv_offset: offset that was returned by qmi_message_tlv_read_init().
  * @offset: address of a the offset within the TLV value.
+ * @endian: source endianness, which will be swapped to host byte order if necessary.
  * @out: return location for the read #gfloat.
  * @error: return location for error or %NULL.
  *
@@ -847,11 +828,38 @@ gboolean qmi_message_tlv_read_sized_guint (QmiMessage  *self,
  *
  * Since: 1.12
  */
-gboolean qmi_message_tlv_read_gfloat (QmiMessage  *self,
-                                      gsize        tlv_offset,
-                                      gsize       *offset,
-                                      gfloat      *out,
-                                      GError     **error);
+gboolean qmi_message_tlv_read_gfloat_endian (QmiMessage  *self,
+                                             gsize        tlv_offset,
+                                             gsize       *offset,
+                                             QmiEndian    endian,
+                                             gfloat      *out,
+                                             GError     **error);
+
+/**
+ * qmi_message_tlv_read_gdouble:
+ * @self: a #QmiMessage.
+ * @tlv_offset: offset that was returned by qmi_message_tlv_read_init().
+ * @offset: address of a the offset within the TLV value.
+ * @endian: source endianness, which will be swapped to host byte order if necessary.
+ * @out: return location for the read #gdouble.
+ * @error: return location for error or %NULL.
+ *
+ * Reads a 64-bit floating-point number from the TLV.
+ *
+ * @offset needs to point to a valid @gsize specifying the index to start
+ * reading from within the TLV value (0 for the first item). If the variable
+ * is successfully read, @offset will be updated to point past the read item.
+ *
+ * Returns: %TRUE if the variable is successfully read, otherwise %FALSE is returned and @error is set.
+ *
+ * Since: 1.22
+ */
+gboolean qmi_message_tlv_read_gdouble (QmiMessage  *self,
+                                       gsize        tlv_offset,
+                                       gsize       *offset,
+                                       QmiEndian    endian,
+                                       gdouble     *out,
+                                       GError     **error);
 
 /**
  * qmi_message_tlv_read_string:
@@ -1004,25 +1012,6 @@ void qmi_message_set_transaction_id (QmiMessage *self,
 /*****************************************************************************/
 /* Printable helpers */
 
-/**
- * qmi_message_get_printable:
- * @self: a #QmiMessage.
- * @line_prefix: prefix string to use in each new generated line.
- *
- * Gets a printable string with the contents of the whole QMI message.
- *
- * If known, the printable string will contain translated TLV values as well as the raw
- * data buffer contents.
- *
- * Returns: (transfer full): a newly allocated string, which should be freed with g_free().
- *
- * Since: 1.0
- * Deprecated: 1.18: Use qmi_message_get_printable_full() instead.
- */
-G_DEPRECATED_FOR (qmi_message_get_printable_full)
-gchar *qmi_message_get_printable (QmiMessage  *self,
-                                  const gchar *line_prefix);
-
 /**
  * qmi_message_get_printable_full:
  * @self: a #QmiMessage.
